==> piwigo-2.5.3.zip: piwigo/language/sh_RS/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+


$lang['Installation'] = 'Instalacija';
$lang['Basic configuration'] = 'Osnovna podešenja';
$lang['Default gallery language'] = 'Podrazumevani jezik galerije';
$lang['Database configuration'] = 'Podešavanje baze';
$lang['Admin configuration'] = 'Administratorska podešenja';
$lang['Start Install'] = 'Pokreni instalaciju';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'mail adresa mora biti u formatu xxx@yyy.eee (primer : milos@firma.org)';
$lang['Webmaster login'] = 'Webmaster pristup';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Bice prikazano posetiocima. Neophodno je za administraciju stranice';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Konekcija na server uspešna, ali konecija na bazu je nemoguca';
$lang['Can\'t connect to server'] = 'Nemoguce povezivanje na server';
$lang['Host'] = 'Host';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['User'] = 'Korisnik';
$lang['user login given by your host provider'] = 'korisnicko ime dat od strane Vašeg host distributera';
$lang['Password'] = 'Lozinka';
$lang['user password given by your host provider'] = 'korisnicka lozinka data od strane Vašeg host distributera ';
$lang['Database name'] = 'Ime baze';
$lang['also given by your host provider'] = 'takode dato od Vašeg Host distributera';
$lang['Database table prefix'] = 'Prefix tabele baze';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'ime tabele baze will bice prefix sa njim (omogucava da upravljate bolje Vašuim tabelama)';
$lang['enter a login for webmaster'] = 'Unesi pristupne podatke za webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'pristupni podaci za webmastera ne mogu sadržati znake \' ili "';
$lang['please enter your password again'] = 'molim unesite Vašu lozinku ponovo';
$lang['Webmaster password'] = 'Webmaster lozinka';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Sacuvajte u tajnosti, omogucava pristup administratorskom delu';
$lang['Password [confirm]'] = 'Lozinka[potvrdi]';
$lang['verification'] = 'Provera';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Potrebna Vam je pomoc? Pitajte na  <a href="%s">Piwigo tabli za poruke</a>.';
$lang['Webmaster mail address'] = 'E-mail adresa Webmaster-a';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Posetioci ce biti u mogucnosti da koriste ovaj mail da kontaktiraju administratora stranice';
$lang['PHP 5 is required'] = 'PHP 5 je neophodan';
$lang['It appears your webhost is currently running PHP %s.'] = 'Izgleda da Vaš webhost trenutno koristi PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo može pokušati da promeni Vašu konfiguraciju na PHP 5 kreiranjem ili menjanjem .htaccess datoteke.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Imajte u vidu da možete sami izmeniti Vašu konfiguraciju restartovati Piwigo posle toga.';
$lang['Try to configure PHP 5'] = 'Pokušajte da podestite PHP 5';
$lang['Sorry!'] = 'Žao nam je!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo wnije uspeo da podesi PHP 5.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Trebalo bi da se obartite podršci Vašeg hosting provajdera za uputstvo kako da promenite na PHP 5 sami.';
$lang['Hope to see you back soon.'] = 'Nadamo se da se uskoro vidimo.';
$lang['Congratulations, Piwigo installation is completed'] = 'Cestitamo, Piwigo instalacija je završena';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Alternativno rešenje je da kopirate tekst iz kutije iznad i nalepite u datoteku "local/config/database.inc.php" (Upozorenje : database.inc.php mora sadržati samo tekst iz kutije, bez linije ili praznih karaktera)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Kreiranje konfiguracione datoteke local/config/database.inc.php neuspešno.';
$lang['Download the config file'] = 'Snimi na racunar konfiguracionu datoteku';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Možete snimiti na racunar konfiguracionu datoteku i poslati je na local/config direktorijum Vaše instalacije.';

$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Ne oklevajte da zatražite pomoć na našem forumu oko bilo čega: %s';
$lang['Just another Piwigo gallery'] = 'Još jedna Piwigo galerija';
$lang['Welcome to my photo gallery'] = 'Dobrodošli u moju foto galeriju';
$lang['Welcome to your new installation of Piwigo!'] = 'Dobrodošli na Vašu novu instalaciju Piwigo-a!';
?>

==> piwigo-2.7.4.zip: piwigo/language/sh_RS/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Instalacija';
$lang['Basic configuration'] = 'Osnovna podešenja';
$lang['Default gallery language'] = 'Podrazumevani jezik galerije';
$lang['Database configuration'] = 'Podešavanje baze';
$lang['Admin configuration'] = 'Administratorska podešenja';
$lang['Start Install'] = 'Pokreni instalaciju';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Bice prikazano posetiocima. Neophodno je za administraciju stranice';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Konekcija na server uspešna, ali konecija na bazu je nemoguca';
$lang['Can\'t connect to server'] = 'Nemoguce povezivanje na server';
$lang['Host'] = 'Host';
$lang['User'] = 'Korisnik';
$lang['user login given by your host provider'] = 'korisnicko ime dat od strane Vašeg host distributera';
$lang['user password given by your host provider'] = 'korisnicka lozinka data od strane Vašeg host distributera ';
$lang['Database name'] = 'Ime baze';
$lang['also given by your host provider'] = 'takode dato od Vašeg Host distributera';
$lang['Database table prefix'] = 'Prefix tabele baze';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'ime tabele baze will bice prefix sa njim (omogucava da upravljate bolje Vašuim tabelama)';
$lang['enter a login for webmaster'] = 'Unesi pristupne podatke za webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'pristupni podaci za webmastera ne mogu sadržati znake \' ili "';
$lang['please enter your password again'] = 'molim unesite Vašu lozinku ponovo';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Sacuvajte u tajnosti, omogucava pristup administratorskom delu';
$lang['Password [confirm]'] = 'Lozinka[potvrdi]';
$lang['verification'] = 'Provera';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Potrebna Vam je pomoc? Pitajte na  <a href="%s">Piwigo tabli za poruke</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Posetioci ce biti u mogucnosti da koriste ovaj mail da kontaktiraju administratora stranice';
$lang['PHP 5 is required'] = 'PHP 5 je neophodan';
$lang['It appears your webhost is currently running PHP %s.'] = 'Izgleda da Vaš webhost trenutno koristi PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo može pokušati da promeni Vašu konfiguraciju na PHP 5 kreiranjem ili menjanjem .htaccess datoteke.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Imajte u vidu da možete sami izmeniti Vašu konfiguraciju restartovati Piwigo posle toga.';
$lang['Try to configure PHP 5'] = 'Pokušajte da podestite PHP 5';
$lang['Sorry!'] = 'Žao nam je!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo wnije uspeo da podesi PHP 5.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Trebalo bi da se obartite podršci Vašeg hosting provajdera za uputstvo kako da promenite na PHP 5 sami.';
$lang['Hope to see you back soon.'] = 'Nadamo se da se uskoro vidimo.';
$lang['Congratulations, Piwigo installation is completed'] = 'Cestitamo, Piwigo instalacija je završena';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Alternativno rešenje je da kopirate tekst iz kutije iznad i nalepite u datoteku "local/config/database.inc.php" (Upozorenje : database.inc.php mora sadržati samo tekst iz kutije, bez linije ili praznih karaktera)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Kreiranje konfiguracione datoteke local/config/database.inc.php neuspešno.';
$lang['Download the config file'] = 'Snimi na racunar konfiguracionu datoteku';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Možete snimiti na racunar konfiguracionu datoteku i poslati je na local/config direktorijum Vaše instalacije.';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Ne oklevajte da zatražite pomoć na našem forumu oko bilo čega: %s';
$lang['Just another Piwigo gallery'] = 'Još jedna Piwigo galerija';
$lang['Welcome to my photo gallery'] = 'Dobrodošli u moju foto galeriju';
$lang['Welcome to your new installation of Piwigo!'] = 'Dobrodošli na Vašu novu instalaciju Piwigo-a!';
$lang['localhost or other, supplied by your host provider'] = 'localhost ili drugi naziv koji ste dobili od provajdera';
